<p align="center"><img src="https://i.ibb.co/qWng9kZ/wrench.png" alt="Equipment python framework" height="200" /></p>

[![PyPI version](https://badge.fury.io/py/equipment.svg)](https://badge.fury.io/py/equipment)

# Equipment

The root of your next python project

## Docs

Project documentation is placed on [the wiki](https://github.com/rogervila/equipment/wiki)

## License

This project is open-sourced software licensed under the [MIT license](https://opensource.org/licenses/MIT).

Equipment icons created by <a href="https://www.flaticon.com/free-icons/toolbox">Freepik - Flaticon</a>
